@@ -1,6 +1,12 @@
 from __future__ import annotations
 
 
+class SecurityWarning(UserWarning):
+    """Base class for warnings of security issues."""
+
+    pass
+
+
 class JoseError(Exception):
     """Base Exception for all errors in joserfc."""
 
@@ -143,7 +149,7 @@ class InvalidCEKLengthError(JoseError):
     error = "invalid_cek_length"
     description = "Invalid 'cek' length"
 
-    def __init__(self, cek_size: int):
+    def __init__(self, cek_size: int):  # pragma: no cover
         description = f"A key of size {cek_size} bits MUST be used"
         super(InvalidCEKLengthError, self).__init__(description=description)
 
